<template>
    <div>
        <div style="margin-top: 10px;">
            <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch"
                label-width="68px">
                <el-form-item label="月份" prop="deptName">
                    <el-date-picker v-model="value1" type="date" placeholder="选择日期">
                    </el-date-picker>
                </el-form-item>
                <el-form-item>
                    <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">查询</el-button>
                </el-form-item>
            </el-form>
        </div>

        <div>
            <el-calendar v-model="value">
                <template slot="dateCell" slot-scope="{date, data}">
                    <div class="main-cd" @click="addPlan(date)">
                        <div class="calendar-day">
                            {{ data.day.split("-").slice(2).join("-") }} {{ data.isSelected ? '✔️' : '' }}
                        </div>
                        <div v-for="(item, index) in calendarData" :key="index" class="is-selected"
                            @click.stop="addPlan(item)">
                            <span v-if="item.day == data.day && item.timeDetailsList">
                                <el-tooltip placement="top">
                                    <div slot="content">
                                        <div v-for="items in item.timeDetailsList" :key="items.day">
                                            {{ items.channelName }} :
                                            {{ items.wechatNumber }}个微信号，
                                            计划投放{{ items.planNumber }}，
                                            实际加人
                                            {{ items.realityNumber }}
                                        </div>
                                    </div>
                                    // 这里写两遍是因为一个是框里展示，一个是悬浮组件内展示的内容
                                    <div v-for="items in item.timeDetailsList" :key="items.day">
                                        {{ items.channelName }} :
                                        {{ items.wechatNumber }}个微信号，
                                        计划投放{{ items.planNumber }}，
                                        实际加人
                                        {{ items.realityNumber }}
                                    </div>
                                </el-tooltip>
                            </span>
                        </div>
                    </div>
                </template>
            </el-calendar>
        </div>

        <!-- 添加或修改规则+病种对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="1000px" append-to-body>
            <div style="margin-bottom: 10px;">时间：{{ time }}</div>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px" :inline="true">
                <el-form-item label="标题" prop="title">
                    <el-input v-model="form.title" placeholder="请输入标题" style="width:200px" />
                </el-form-item>
                <el-form-item label="事件" prop="event">
                    <el-input v-model="form.event" placeholder="请输入事件" style="width:200px" />
                </el-form-item>
                <el-form-item label="日期类型" prop="dateType">
                    <el-select v-model="form.dateType" style="width: 94%">
                        <el-option v-for="dict in dict.type.memo_date_type" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="时间点" prop="mTime" v-if="form.dateType == 1">
                    <el-time-picker v-model="form.mTime" :picker-options="{
                        selectableRange: '18:30:00 - 20:30:00'
                    }" placeholder="任意时间点">
                    </el-time-picker>
                </el-form-item>
                <el-form-item label="重复提醒" prop="isRepeat">
                    <el-select v-model="form.isRepeat" style="width: 94%">
                        <el-option v-for="dict in dict.type.sys_yes_no" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="提醒间隔" prop="repeatTime" v-if="form.isRepeat == 'Y'">
                    <el-input type="number" v-model="form.repeatTime" placeholder="请输入提醒间隔" style="width:200px"
                    oninput="value=value.replace(/[^0-9.]/g,'')" />
                </el-form-item>
                <el-form-item label="备忘状态" prop="mFlag">
                    <el-select v-model="form.mFlag" style="width: 94%">
                        <el-option v-for="dict in dict.type.memo_status" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="紧急状态" prop="stateLevel">
                    <el-select v-model="form.stateLevel" style="width: 94%">
                        <el-option v-for="dict in dict.type.memo_state_level" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="备注" prop="remark">
                    <el-input v-model="form.remark" placeholder="请输入备注" style="width:200px" />
                </el-form-item>
            </el-form>
            <el-button style="margin: 10px 10px" type="primary" plain size="mini" icon="el-icon-plus"
                @click="hableadd">添加</el-button>
            <el-table :data="cateringList" border>
                <el-table-column type="selection" width="55" align="center" />
                <el-table-column label="序号" align="center" prop="newID" width="55px" />
                <el-table-column label="标题" align="center" prop="title" />
                <el-table-column label="事件" align="center" prop="event" />
                <el-table-column label="日期类型" align="center" prop="dateType" />
                <el-table-column label="时间点" align="center" prop="mTime" />
                <el-table-column label="重复提醒" align="center" prop="isRepeat" width="150px" />
                <el-table-column label="提醒间隔" align="center" prop="repeatTime" width="150px" />
                <el-table-column label="备忘状态" align="center" prop="mFlag" width="150px" />
                <el-table-column label="紧急状态" align="center" prop="stateLevel" width="150px" />
                <el-table-column label="备注" align="center" prop="remark" width="150px" />
                <el-table-column label="操作" align="center" class-name="small-padding fixed-width" fixed="right"
                    width="80px">
                    <template slot-scope="scope">
                        <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                            v-hasPermi="['catering:catering:edit']" title="修改">
                        </el-button>
                        <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete1(scope.row)"
                            v-hasPermi="['catering:catering:remove']" title="删除">
                        </el-button>
                    </template>
                </el-table-column>
            </el-table>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>

    </div>
</template>
<script>
export default {
    dicts: [
        "memo_state_level",
        "memo_status",
        "memo_date_type",
        "sys_yes_no",
        "reservation_pay_type",
        "sys_normal_disable"
    ],
    data() {
        return {
            // 显示搜索条件
            showSearch: true,
            queryParams: {

            },
            title: "",
            value1: '',
            time: '',
            open: false,
            value: new Date(),
            calendarData: [],
            form: {
                mTime: new Date(2016, 9, 10, 18, 40),
            },
            cateringList: [],
            // 表单校验
            rules: {
                title: [
                    { required: true, message: "标题不能为空", trigger: "change" },
                ],
            },
        }
    },
    monthChange(val) {
        // 这里是监听时间变化 => @change="monthChange"，然后传入日历组件
        this.value = val;
        // 时间切换的时候，顺便调个接口查询当月数据
        this.editDetail();
    },
    methods: {
        editDetail() {

        },
        handleQuery() {

        },
        addPlan(val) {
            this.open = true
            this.title = "新增日计划"
            this.timestampToTime(val)
        },
        timestampToTime(timestamp) {
            var date = new Date(timestamp);
            var y = date.getFullYear();
            var m = date.getMonth() + 1;
            m = m < 10 ? ('0' + m) : m;
            var d = date.getDate();
            d = d < 10 ? ('0' + d) : d;
            var h = date.getHours();
            var minute = date.getMinutes();
            minute = minute < 10 ? ('0' + minute) : minute;
            var second = date.getSeconds();
            second = second < 10 ? ('0' + second) : second;
            this.time = y + '-' + m + '-' + d;
        },
        hableadd() {
            this.cateringList.push(this.form)
            this.form = {}
        },
        cancel() {
            this.open = false
        },
        submitForm() {

        },
        handleDelete1(row) {
            this.cateringList.splice(row, 1)
        },
      

    }
}
</script>
<style>
::v-deep .el-calendar-table:not(.is-range) td.next {
    display: none;
}

::v-deep .el-calendar-table:not(.is-range) td.prev {
    visibility: hidden;
}

::v-deep .el-calendar__button-group {
    display: none;
}


/* 取消[type='number']的input的上下箭头 */
input::-webkit-inner-spin-button {
    -webkit-appearance: none !important;
}

input::-webkit-outer-spin-button {
    -webkit-appearance: none !important;
}

input[type='number'] {
    -moz-appearance: textfield;
}
</style>